@@ -22,7 +22,6 @@ use Badger::Class
     words     => 'ID EXCEPTION THROWS ERROR DECLINED before after',
     constant  => { 
         base_id => 'Badger',      # stripped from class name to make id
-        TRIAL   => 'Badger::Base::Trial',
     };
 
 use Badger::Exception;              # TODO: autoload
@@ -48,7 +47,7 @@ our $MESSAGES  = {
 
 sub new {
     my $class = shift;
-    if (DEBUG && ((@_ == 1 && ref $_[0] ne HASH) || (@_ > 2 and @_ % 2))) {
+    if ($DEBUG && ((@_ == 1 && ref $_[0] ne HASH) || (@_ > 2 and @_ % 2))) {
         # catch any "Odd number of elements..." warnings before they happen
         # so we can report where this method was called from.
         my ($pkg, $file, $line) = caller();
@@ -59,13 +58,8 @@ sub new {
     }
     my $args  = @_ && ref $_[0] eq HASH ? shift : { @_ };
     my $self  = bless { }, ref $class || $class;
-       $self  = $self->init($args);
-
-    # be careful to account for object that overload the boolean comparison
-    # operator and may return false to a simple truth test.
-    return defined $self
-        ? $self
-        : $self->error("init() method failed\n");
+    return $self->init($args)
+        || $self->error("init() method failed\n");
 }
 
 sub init {
@@ -83,7 +77,7 @@ sub warn {
     my $message  = join(BLANK, @_);
     my $handlers = $self->on_warn;
 
-    $self->debug("dispatching handlers for warn: ", $self->dump_data_inline($handlers), "\n") if DEBUG;
+    $self->debug("dispatching handlers for warn: ", $self->dump_data_inline($handlers), "\n") if $DEBUG;
     $self->_dispatch_handlers( warn => $handlers => $message )
         if $handlers && @$handlers;
     
@@ -131,7 +125,7 @@ sub decline {
     my $self   = shift;
     my $class  = ref     $self || $self;
     my $type   = reftype $self || BLANK;
-    my $reason = @_ == 1 ? shift : join(BLANK, @_);
+    my $reason = join(BLANK, @_);
     no strict   REFS;
     no warnings ONCE;
     
@@ -182,11 +176,11 @@ sub throw {
         #   throw($info)
         
         if (blessed $type && $type->isa($emod)) {
-            $self->debug("returning exception object: ", ref $type, " => [$type]\n") if DEBUG;
+            $self->debug("returning exception object: ", ref $type, " => $type\n") if $DEBUG;
             $e = $type;
         }
         else {
-            $self->debug("creating new exception object chain: info => $type\n") if DEBUG;
+            $self->debug("creating new exception object chain: info => $type\n") if $DEBUG;
             $e = $emod->new( type => $self->throws, info => $type );
         }
     }
@@ -210,23 +204,18 @@ sub throw {
             # construct a new exception from $type and $info fields
             $config->{ type } = $type;
             $config->{ info } = $info;
-            $self->debug("creating new exception object: ", $self->dump_hash($config), "\n") if DEBUG;
+            $self->debug("creating new exception object: ", $self->dump_hash($config), "\n") if $DEBUG;
             $e = $emod->new($config);
         }
     }
-    $e->throw;
+    die $e;
 }
 
 sub try {
-    my $self = shift;
-    if (@_) {
-        my $method = shift;     # || return $self->error_msg( missing_to => method => 'try' );
-        eval { $self->$method(@_) }
-            || $self->decline($@);
-    }
-    else {
-        return TRIAL->_bind_($self);
-    }
+    my $self   = shift;
+    my $method = shift || return $self->error_msg( missing_to => method => 'try' );
+    eval { $self->$method(@_) }
+        || $self->decline($@);
 }
 
 sub catch {
@@ -238,7 +227,6 @@ sub catch {
 sub throws {
     my $self  = shift;
     my $type  = reftype $self || BLANK;
-    my $class = class($self);
     my $throws;
     
     if (@_) {
@@ -246,7 +234,7 @@ sub throws {
         # else (classes and non-hash objects) use the $THROWS package var
         $throws = $type eq HASH
             ? ($self->{ THROWS } = shift)
-            :  $class->var(THROWS, shift);
+            :  $self->class->var(THROWS, shift);
     }
     elsif ($type eq HASH) {
         # we also look in $self->{ config } to see if a 'throws' was 
@@ -255,11 +243,11 @@ sub throws {
               ||= $self->{ config } 
               &&  $self->{ config }->{ throws };
     }
-    
+
     # fall back on looking for any package variable in class / base classes
     return $throws 
-        || $class->any_var(THROWS)
-        || $class->id;
+        || $self->class->any_var(THROWS)
+        || $self->class->id;
 }
 
 sub exception {
@@ -272,15 +260,14 @@ sub exception {
         # like a hash when it is a hash-based object
         $emod = $type eq HASH
             ? ($self->{ EXCEPTION } = shift)
-            : class($self)->var(EXCEPTION, shift);
+            :  $self->class->var(EXCEPTION, shift);
     }
     elsif ($type eq HASH) {
         $emod = $self->{ EXCEPTION }
             ||= $self->{ config }
             &&  $self->{ config }->{ exception };
     }
-    return $emod 
-        || class($self)->any_var(EXCEPTION);
+    return $emod || $self->class->any_var(EXCEPTION);
 }
 
 sub fatal {
@@ -310,36 +297,26 @@ sub message {
     my $self   = shift;
     my $name   = shift 
         || $self->fatal("message() called without format name");
-    my $format = class($self)->hash_value( MESSAGES => $name )
+    my $format = $self->class->hash_value( MESSAGES => $name )
         || $self->fatal("message() called with invalid message type: $name");
     xprintf($format, @_);
 }
 
 sub warn_msg {
+    my $self = shift;
     # explicitly quantify local message() method in case a subclass decides
     # to re-implement the message() method to do something else
-    $_[0]->warn( message(@_) );
+    $self->warn( $self->Badger::Base::message(@_) );
 }
 
 sub error_msg {
-    $_[0]->error( message(@_) );
-}
-
-sub fatal_msg {
-    $_[0]->fatal( message(@_) );
+    my $self = shift;
+    $self->error( $self->Badger::Base::message(@_) );
 }
 
 sub decline_msg {
-    $_[0]->decline( message(@_) );
-}
-
-sub debug_msg {
-    $_[0]->debug( message(@_) );
-}
-
-sub throw_msg {
     my $self = shift;
-    $self->throw( shift, message($self, @_) );
+    $self->decline( $self->Badger::Base::message(@_) );
 }
 
 
@@ -375,7 +352,7 @@ class->methods(
         
         $on_event => sub {
             my $self  = shift;
-            my $class = class($self);
+            my $class = $self->class;
             my $list;
     
             if (ref $self && reftype $self eq HASH) {
@@ -387,7 +364,7 @@ class->methods(
                 # careful!  the config value might be a single handler
                 $list = $self->{ $ON_EVENT } = [$list]
                     unless ref $list eq ARRAY;
-                $self->debug("got $on_event handlers: ", $self->dump_data_inline($list), "\n") if DEBUG
+                $self->debug("got $on_event handlers: ", $self->dump_data_inline($list), "\n") if $DEBUG
             }
             else {
                 # class method or non-hash objects use pkg vars only
@@ -428,11 +405,11 @@ class->methods(
 sub _dispatch_handlers {
     my ($self, $type, $handlers, @args) = @_;
 
-    $self->debug("_dispatch handlers: ", $self->dump_data_inline($handlers), "\n") if DEBUG;
+    $self->debug("_dispatch handlers: ", $self->dump_data_inline($handlers), "\n") if $DEBUG;
 
     foreach (@$handlers) {
         my $handler = $_;        # don't alias list items
-        $self->debug("dispatch handler: $handler\n") if DEBUG;
+        $self->debug("dispatch handler: $handler\n") if $DEBUG;
         if (! ref $handler) {
             if ($handler eq WARN) {         # 'warn' - we make sure that the 
                 my $msg = join('', @args);  # message is newline terminated
@@ -454,46 +431,17 @@ sub _dispatch_handlers {
         else {
             $self->fatal("Invalid on_$type handler: $handler");
         }
-        $self->debug("mid-dispatch args: [", join(', ', @args), "]\n") if DEBUG;
+        $self->debug("mid-dispatch args: [", join(', ', @args), "]\n") if $DEBUG;
         # bail out if we got an empty list of return values or a single
         # false value
         last if ! @args || @args == 1 && ! $args[0];
     }
-    $self->debug("returning ", join(', ', @args), "\n") if DEBUG;
+    $self->debug("returning ", join(', ', @args), "\n") if $DEBUG;
     return @args;
 }
     
 
 
-#-----------------------------------------------------------------------
-# Badger::Base::Trial - monadic object for $object->try operation
-#-----------------------------------------------------------------------
-
-package Badger::Base::Trial;
-our $AUTOLOAD;
-
-sub _bind_ {
-    my ($class, $object) = @_;
-    bless \$object, ref $class || $class;
-}
-
-sub AUTOLOAD {
-    my $self = shift;
-    my ($name) = ($AUTOLOAD =~ /([^:]+)$/ );
-    return if $name eq 'DESTROY';
-
-    # call method on target object in eval block, and downgrade
-
-    my $result = eval { $$self->$name(@_) };
-#    $$self->debug("result ($@): [", defined $result ? $result : '<undef>', ']');
-    return defined $result
-        ? $result
-        : $$self->decline($@);
-    
-    # TODO: catch missing error methods
-}
-
-
 1;
 __END__
 
@@ -1116,11 +1064,6 @@ The L<reason()> method can be used to return the message generated.
     my $food = $forager->forage('nuts')
         || warn $forager->reason;       # No nuts found in the forest
 
-=head2 fatal_msg($message, @args)
-
-This is a wrapper around the L<fatal()> and L<message()> methods,
-similar to L<error_msg()> and co.
-
 =head2 throw($type, $info, %more_info)
 
 This method throws an exception by calling C<die()>.  It can be called
@@ -1175,28 +1118,6 @@ thrown in the previous example, that would be:
 
     propulsion error - engine error - warp drive offline
 
-=head2 throw_msg($type, $message, @args)
-
-This is a wrapper around the L<throw()> and L<message()> methods for throwing
-custom exceptions using message formats to generate the error information
-string. The first argument defines the exception type. The second is the name
-of the message format. The remaining arguments are uses to populate the
-placeholders in the message format.
-
-    our $MESSAGES = {
-        offline => '%s is offline',
-    };
-
-    sub engage {
-        my $self = shift;
-        $self->throw_msg( warp => offline => 'warp drive' )
-            unless $self->warp_drive_ready;
-        # make it so
-    }
-    
-    # throws the following exception:
-    warp error - warp drive is offline
-
 =head2 try($method, @args)
 
 This method wraps another method call in an C<eval> block to catch any
@@ -1215,16 +1136,6 @@ The error thrown can be retrieved using the C<reason()> method.
         42;     # a sensible default
     };
 
-If you call the C<try()> method without any arguments then it will return a
-C<Badger::Base::Trial> object as a wafer thin wrapper around the original 
-object.  Any methods called on this delegate object will be forwarded to 
-the original object, wrapped up in an C<eval> block to catch any errors
-thrown.
-
-    my $result = $object->try->fetch('answer') ||= do { 
-        ...
-    };
-
 =head2 catch($type, $method, @args)
 
 TODO - this method depends on some code in L<Badger::Exception> which
@@ -1405,29 +1316,6 @@ number where the message was generated.
         $self->debug('leaving example()');
     }
 
-=head2 debug_msg($message, @args)
-
-This is a wrapper around the L<debug()> and L<message()> methods,
-similar to L<warn_msg()>, L<error_msg()> and friends.
-
-    our $MESSAGES = {
-        here => 'You are in %s',
-    };
-    
-    sub example {
-        my $self = shift;
-        
-        $self->debug_msg( 
-            here => 'a maze of twisty little passages, all alike' 
-        ) if DEBUG;
-        
-        # ... some code ...
-        
-        $self->debug_msg( 
-            here => 'boat, floating on a sea of purest green' 
-        ) if DEBUG;
-    }
-    
 =head2 debug_up($level,$msg1,$msg2,...)
 
 Another debugging method mixed in from L<Badger::Debug>.  This is a wrapper
@@ -1701,7 +1589,7 @@ Andy Wardley L<http://wardley.org/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 1996-2009 Andy Wardley.  All Rights Reserved.
+Copyright (C) 1996-2008 Andy Wardley.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
