@@ -15,11 +15,11 @@ package Badger::Codec::YAML;
 use Badger::Class
     version => 0.01,
     base    => 'Badger::Codec',
-    import  => 'class CLASS';
+    import  => 'class';
 
 BEGIN {
     eval { require 'YAML.pm' } 
-        || CLASS->error("You don't have YAML installed");
+        || class->error("You don't have YAML installed");
 }
 
 sub encode {
@@ -90,11 +90,11 @@ all the decoding work, i.e. the C<Load()> subroutine in L<YAML>.
 
 =head1 AUTHOR
 
-Andy Wardley L<http://wardley.org/>
+Andy Wardley E<lt>abw@wardley.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2009 Andy Wardley. All rights reserved.
+Copyright (C) 2005-2008 Andy Wardley. All rights reserved.
 
 =head1 SEE ALSO
 
