@@ -13,9 +13,10 @@
 package Badger::Rainbow;
 
 use Carp;
-#use Badger::Debug ':debug';
+use Badger::Debug 'debug';
 use Badger::Class
     version   => 0.01,
+    debug     => 0,
     base      => 'Badger::Exporter',
     constants => 'DELIMITER ARRAY REFS PKG',
     exports   => {
@@ -39,8 +40,6 @@ use Badger::Class
         },
     };
 
-# can't import this via Badger::Debug as it depends on Badger::Rainbow
-our $DEBUG = 0 unless defined $DEBUG;
 
 sub _export_ANSI_colours {
     my ($class, $target, $symbol, $more_symbols) = @_;
@@ -54,7 +53,7 @@ sub _export_ANSI_colours {
         unless ref $cols eq ARRAY;
 
     foreach my $col (@$cols) {
-#        $class->debug("Exporting ANSI clolour $col to $target\n") if $DEBUG;
+        $class->debug("Exporting ANSI clolour $col to $target\n") if $DEBUG;
         my $val = $ansi->{ $col }
             || croak "Invalid ANSI colour specified to import: $col";
         *{ $target.PKG.$col } = sub(@) {
@@ -72,7 +71,7 @@ sub _export_ANSI_colours {
 
 sub ANSI_escape {
     my $attr = shift;
-    my $text = join('', grep { defined $_ } @_);
+    my $text = join('', @_);
     return join("\n", 
         map {
             # look for an existing escape start sequence and add new 
@@ -151,7 +150,7 @@ Andy Wardley L<http://wardley.org/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 1996-2009 Andy Wardley.  All Rights Reserved.
+Copyright (C) 1996-2008 Andy Wardley.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
